/*==========================================================*
Project: 		EBRD-IFS Mongolia

Purpose:		Cleans data...
				
Code Author: 	IFS 
Date created: 	April 2014
Last modified:  see "readme"-file for info
*===========================================================*/

*-- GLOBALS:
	global Loan "loan loans f_l_mfi f_l_bank f_l_percB f_lamount_mfi f_lamount_bank f_loanamount"
	global T3 "assetvalueTR3p inventory bm_revenue bm_revenueTR1p bm_expenses bm_profit bm_profitTR1p bm_profitcalc y_selfempl bm_own bm_service bm_agric b_start b_close bm_profit01"
	global T4Income01 "y_selfempl yval_selfempl y_wages yval_wages y_agric yval_agric y_shop yval_shop y_manuf yval_manuf y_privb yval_privb y_governmnt yval_governmnt y_remit yval_remit y_benefit yval_benefit y_pension yval_pension y_rent"
	global LabourSupply "$AllAdults $AllAdultsPM $Teens $TeensPM $Teens1619 $Teens1619PM"
		global AllAdults "hrswork_1664 hrswork_bus1664 hrswork_oa1664"
		global AllAdultsPM "hrswork_1664pm hrswork_bus1664pm hrswork_oa1664pm"
		global Teens "hrswork_teen hrswork_busteen hrswork_oateen"
		global TeensPM "hrswork_teenpm hrswork_busteenpm hrswork_oateenpm"
		global Teens1619 "hrswork_tot1619 hrswork_bus1619 hrswork_oa1619"
		global Teens1619PM "hrswork_pm1619 hrswork_buspm1619 hrswork_oa1619pm"
	global YvarCons "totalc totalc_cap totalcTR foodc_h foodc_o foodc educ_yr educ_yrTR temptation_yr cigalcc  nondc durablec durableTR nondcTR nondc_tot nondcTR_tot recre_yr HDGI"
	global YvarSav "savings_avg savings_yn contrib_weekly contrib_monthly contrib_yearly contrib_no sav_busexp sav_edu sav_med sav_old sav_repair sav_emergency"
	
	
*+++++++++++++++++++++++++++*
* (Table 2) - Credit        *
*+++++++++++++++++++++++++++*
	
	//Generate additional variables 
	egen f_l_mfi=rowmax(l1_2 l2_2 l3_2)
	la var f_l_mfi "=1 if one of outstanding loans is with MFI"
	egen f_l_bank=rowmax(l1_1 l2_1 l3_1)
	la var f_l_mfi "=1 if one of outstanding loans is with Bank"
	egen f_l_percB=rowmean(l1_percbus l2_percbus l3_percbus)
	la var f_l_percB "Average percentage of 3 main outstanding loans used for business investment"
	forvalues i=1(1)3 {
		gen temp`i'_mfi=l`i'_amount if l`i'_2==1
		gen temp`i'_bank=l`i'_amount if l`i'_1==1
		}
	egen f_lamount_mfi=rowmean(temp1_mfi temp2_mfi temp3_mfi)
	egen f_lamount_bank=rowmean(temp1_bank temp2_bank temp3_bank)
	foreach x of varlist f_lamount_mfi f_lamount_bank {
		replace `x'=0 if `x'==.
		replace `x'=. if `x'==999999
		replace `x'=. if `x'==99999
		}
	egen f_loanamount=rowtotal(l1_amount l2_amount l3_amount) 
	gen loan=loans!=0 
	su loan loans f_l_mfi f_l_bank f_l_percB f_lamount_mfi f_lamount_bank f_loanamount
	foreach x of varlist loan loans f_l_mfi f_l_bank f_l_percB f_lamount_mfi f_lamount_bank f_loanamount {
		replace `x'=0 if `x'==. & followup==1
		}


*+++++++++++++++++++++++++++++++++++++*
* (Table 3) - (Self-Empl Activities)  *
*+++++++++++++++++++++++++++++++++++++*
	/* Variables:	- Asset (stock): 						--	inventory, assetvalue
					- Investment in last 12 months			--	??...
					- Sales + home consumption				--	?? bm_revenues (incl trimmed)
					- Expenses								-- 	bm_expenses (incl trimmed)
					- Profit 								--	bm_profit (incl trimmed)
					- Has a self-employment activity		--	bm_own bm_service bm_agric
					- Number of self employment activities	--	WE DON'T HAVE THIS
					- has started a business (last yr)		--	b_start
					- Has closed a business (last yr)		--	b_close
					
					14.11.: add dummy for having some profits -- bm_profit01
					4.02.2014: add employment of staff outside of the HH (bm_staff_outft bm_staff_outpt bm_staff_outt)
					*/
	
	//Generate additional variables 
	gen inventory=inventory_val!=0
	gen b_start=1 if b_bm_own==0 & bm_own==1
		la var b_start "=1 if HH has started a business (since baseline)"
	gen b_close=1 if b_bm_own==1 & bm_own==0
		la var b_close "=1 if HH has closed their business (since baseline)"
	gen bm_profit01=bm_profit!=0
		replace bm_profit01=. if bm_profit==.
	egen staff_out=rowtotal(bm_staff_outft bm_staff_outpt bm_staff_outt)
	egen staff_hh=rowtotal(bm_staff_hhft bm_staff_hhpt bm_staff_hht)
	gen bm_profitcalc=bm_revenue-bm_expenses
	
	global T3 "assetvalue* inventory bm_revenue* bm_expenses* bm_profit* bm_profitcalc* y_selfempl bm_own bm_service bm_agric b_start b_close bm_profit01"
	global T3staff "bm_staff_outft bm_staff_outpt bm_staff_outt staff_out bm_staff_hhft bm_staff_hhpt bm_staff_hht staff_hh"

	foreach x of varlist $T3 $T3staff {
		*replace `x'=. if followup==0 			// this should anyway be missing, but just to be on the safe side
		replace `x'=0 if `x'==. & followup==1
		replace `x'=. if followup==0
		}
	foreach x of varlist bm_expenses bm_revenue bm_profit bm_profitcalc assetvalue {
			su `x', d
			gen `x'TR1p=`x' if `x'<=r(p99)
			su `x'TR1p, d
			gen `x'TR2p=`x' if `x'<=r(p99)
			su `x'TR2p, d
			gen `x'TR3p=`x' if `x'<=r(p99)
			}

	
*++++++++++++++++++++++*
* (Table 4) - Income   *
*++++++++++++++++++++++*
	foreach x of varlist y_selfempl y_agric y_shop y_manuf  y_privb y_governmnt y_remit y_benefit y_pension y_rent {
		replace `x'=0 if `x'==.
		replace `x'=. if followup==0
		}
		
	egen y_wages=rowmax(y_agric y_shop y_manuf  y_privb y_governmnt)
	egen yval_wages=rowtotal(yval_agric yval_shop yval_manuf yval_privb yval_governmnt)


*++++++++++++++++++++++++++++*
* (Table 5) - Labour Supply  *
*++++++++++++++++++++++++++++*
	merge 1:1 intervid using "data\Followup\Household level info working hrs and schooling - teenagers.dta"
	*keep if followup==1
	drop _m
	merge 1:1 intervid using "data\Followup\labour supply and schooling outcomes - hh level.dta"
	gen hrswork_tot=0
	gen hrswork_1664=0
	gen hrswork_teen=0
	forvalues i=1(1)9 {
		gen age0`i'=2010- o8_2_g0`i' // create year variable
		replace  o8_9_0`i'=0 if  o8_9_0`i'==.
		replace hrswork_tot=hrswork_tot+ o8_9_0`i'
		replace hrswork_tot=0 if hrswork_tot==.
		replace hrswork_tot=. if followup==0
		replace hrswork_1664=hrswork_1664+ o8_9_0`i' if age0`i'>=16 & age0`i'<=64	// create working hours for HH mem of working age
		replace hrswork_1664=0 if hrswork_1664==.
		replace hrswork_1664=. if followup==0
		replace hrswork_teen=hrswork_teen+ o8_9_0`i' if age0`i'>=13 & age0`i'<=19	// create working hours for HH mem of working age
		replace hrswork_teen=0 if hrswork_teen==.
		replace hrswork_teen=. if followup==0
		}
	forvalues i=10(1)12 {
		gen age`i'=2010- o8_2_g`i'
		replace  o8_9_`i'=0 if  o8_9_`i'==.
		replace hrswork_tot=hrswork_tot+ o8_9_`i'
		replace hrswork_tot=0 if hrswork_tot==.
		replace hrswork_tot=. if followup==0
		replace hrswork_1664=hrswork_1664+ o8_9_`i' if age`i'>=16 & age`i'<=64	// create working hours for HH mem of working age
		replace hrswork_1664=0 if hrswork_1664==.
		replace hrswork_1664=. if followup==0
		replace hrswork_teen=hrswork_teen+ o8_9_`i' if age`i'>=13 & age`i'<=19	// create working hours for ttenage HH mem 
		replace hrswork_teen=0 if hrswork_teen==.
		replace hrswork_teen=. if followup==0
		}
	gen hrswork_bus=0
	gen hrswork_bus1664=0
	gen hrswork_busteen=0
	forvalues i=1(1)9 {
		replace  o8_10_0`i'=0 if  o8_10_0`i'==.
		replace hrswork_bus=hrswork_bus+ o8_10_0`i'
		replace hrswork_bus=0 if hrswork_bus==.
		replace hrswork_bus=. if followup==0
		replace hrswork_bus1664=hrswork_bus1664+ o8_10_0`i' if age0`i'>=16 & age0`i'<=64	// create working hours on bus for HH mem of working age
		replace hrswork_bus1664=0 if hrswork_bus1664==.
		replace hrswork_bus1664=. if followup==0
		replace hrswork_busteen=hrswork_busteen+ o8_10_0`i' if age0`i'>=13 & age0`i'<=19	
		replace hrswork_busteen=0 if hrswork_busteen==.
		replace hrswork_busteen=. if followup==0
		}
	forvalues i=10(1)12 {
		replace  o8_10_`i'=0 if  o8_10_`i'==.
		replace hrswork_bus=hrswork_bus+ o8_10_`i'
		replace hrswork_bus=0 if hrswork_bus==.
		replace hrswork_bus=. if followup==0
		replace hrswork_bus1664=hrswork_bus1664+ o8_10_`i' if age`i'>=16 & age`i'<=64	// create working hours on bus for HH mem of working age
		replace hrswork_bus1664=0 if hrswork_bus1664==.
		replace hrswork_bus1664=. if followup==0
		replace hrswork_busteen=hrswork_busteen+ o8_10_`i' if age`i'>=13 & age`i'<=19	
		replace hrswork_busteen=0 if hrswork_busteen==.
		replace hrswork_busteen=. if followup==0
		}
	replace hrswork_tot=. if hrswork_tot>600
	replace hrswork_1664=. if hrswork_1664>600
	// gen count of nr of childen 16-19 in hh & of working age & teens
	gen count1664=0
	gen countteen=0
	forvalues y=17(1)20 {
		gen count16`y'=0
		forvalues i=1(1)9 {
			replace count16`y'=count16`y'+1 if age0`i'>=16 & age0`i'<=`y'
			}
		forvalues i=10(1)12 {
			replace count16`y'=count16`y'+1 if age`i'>=16 & age`i'<=`y'
			}
		}
	forvalues i=1(1)9 {
		replace count1664=count1664+1 if age0`i'>=16 & age0`i'<=64
		replace countteen=countteen+1 if age0`i'>=13 & age0`i'<=20
		}
	forvalues i=10(1)12 {
		replace count1664=count1664+1 if age`i'>=16 & age`i'<=64
		replace countteen=countteen+1 if age`i'>=13 & age`i'<=20
		}

	egen hhmem=rowtotal(hhmem_male hhmem_female)
	gen hrswork_totpm=hrswork_tot/hhmem
	gen hrswork_buspm=hrswork_bus/hhmem
	gen hrswork_1664pm=hrswork_1664/count1664
	gen hrswork_bus1664pm=hrswork_bus1664/count1664
	gen hrswork_teenpm=hrswork_teen/countteen
	gen hrswork_busteenpm=hrswork_busteen/countteen

	
	gen hrswork_oa1664=hrswork_1664-hrswork_bus1664			// hrs worked on other than business-activities (all hh mem of working age)
	gen hrswork_oa1664pm=hrswork_1664pm-hrswork_bus1664pm	// hrs worked on other than business-activities per hh member (all hh mem of working age)
	gen hrswork_oa1619=hrswork_tot1619-hrswork_bus1619		// hrs worked on other than business-activities (age 16-19)
	gen hrswork_oa1619pm=hrswork_pm1619-hrswork_buspm1619	// hrs worked on other than business-activities per member (age 16-19)
	gen hrswork_oateen=hrswork_teen-hrswork_busteen		// hrs worked on other than business-activities (age 16-19)
	gen hrswork_oateenpm=hrswork_teenpm-hrswork_busteenpm	// hrs worked on other than business-activities per member (age 16-19)
	
		
	foreach x of varlist hrswork_tot  $AllAdults $AllAdultsPM $Teens $TeensPM $Teens1619 $Teens1619PM {
		replace `x'=0 if `x'==.	
		replace `x'=. if followup==0	
		}
	
*++++++++++++++++++++++++++*
* (Table 6) - Consumption  *
*++++++++++++++++++++++++++*
	gen durableTR=durable if durabl<=600000	// exlcudes one obs
	gen nondcTR=nondc if nond<=2800	// exluded one obs
	gen educ_yrTR=educ_yr if educ_yr<25000	//excludes one obs
	
	foreach x of varlist foodc_h foodc_o cigalcc nondc durablec durableTR nondcTR recre_m{
		gen `x'temp=`x'
		replace `x'temp=0 if `x'temp==.
		}
	gen totalc=foodc_htemp*52 +foodc_otemp*52+ cigalcctemp*52 + nondctemp*12+ durablectemp
		lab var totalc "Total consumption expenditure in last year"
	gen totalcTR=foodc_htemp*52 +foodc_otemp*52+ cigalcctemp*52 + nondcTRtemp*12+ durableTRtemp
	gen nondc_tot=nondc+foodc+cigalcc
	gen nondcTR_tot=nondcTR+foodc+cigalcc
	gen temptation_yr=cigalcc+recre_mtemp*12
	gen recre_yr=recre_m*12
	foreach x of varlist totalc totalcTR foodc_h foodc_o foodc educ_yr educ_yrTR temptation_yr cigalcc  nondc durablec durableTR nondcTR nondc_tot nondcTR_tot recre_yr {
		replace `x'=. if followup==0 	
		gen miss_`x'=1 if `x'==. & followup==1
		}
	*egen hhmem=rowtotal(hhmem_male hhmem_female)
	gen totalc_cap=totalc/hhmem
		replace totalc_cap=0 if totalc_cap==. & followup==1
		replace totalc_cap=. if followup==0
	* home durable good index:
	foreach x of varlist house_nr land_nr car_nr lorry_nr animals_nr motorbike_nr computer_nr tools_nr inventory_nr mobile_nr tv_nr video_nr radio_nr electrappl_nr generator_nr fridge_nr oven_nr washmachine_nr {
		gen `x'01=`x'!=0 & `x'!=.
		}
	factor *_nr01, pcf // Principal Component Factor analysis
	rotate
	predict HDGI 

	
*++++++++++++++++++++++*
* (Table 6) - Savings  *
*++++++++++++++++++++++*
	//Generate additional variables 
	replace savings_yn=0 if savings_yn==2
	replace savings_yn=1 if savings_yn==9
	replace savings_yn=0 if savings_yn==.	
	replace savings_yn=. if followup==0	
	replace savings_avg=0 if savings_avg==.	
	replace savings_avg=. if followup==0	
	foreach x of varlist  contrib_weekly contrib_monthly contrib_yearly contrib_no sav_busexp sav_edu sav_med sav_old sav_repair sav_emergency sav_cons sav_bequest sav_debt sav_festival sav_other {
		replace `x'=0 if `x'!=1 & savings_yn==1
		replace `x'=0 if `x'==.	
		replace `x'=. if followup==0	
		}

*+++++++++++++++++++++++++++++++*
* (Table 7) - Have kids & Stress  *
*+++++++++++++++++++++++++++++++*
	rename stress_1 stress
	foreach x of varlist  stress {
		replace `x'=0 if `x'==.
		replace `x'=. if follow==0
		}
	
		merge 1:1 intervid using "data\Followup\Kids1619at followup.dta", nogen
		gen kids1619=kids_1619!=0
		
		
		

	
	