/*==========================================================*
Paper: 		"The impacts of microcredit: Evidence from B&H"

Purpose:		This do-file: 
				Estimates results presented in Table 1 of the 
				paper (Randomization)
\				
Code Author: 	IFS
Date created: 	Feb 2013
Last modified:  

Note:			The working directory path in line 21 needs to 
				be adjusted for the file to run.
				The file is best executed quietly.
				Results are shown on the screen only. 
*===========================================================*/
capture log close
set more off
adopath+"C:\ado"
drop _all
global workdir "XXX"		
cap mkdir "${workdir}"	
cd "${workdir}"						


*-- PUT DATA SET TOGETHER: 
	use "data\Baseline\Covariates Bosnia Baseline.dta", clear
	merge 1:1 intervid using "data\Baseline\BL - SECTION 5 - Income cl.dta", keepusing(yval_selfempl yval_agric) nogen
	merge 1:1 intervid using "data\Baseline\BL - SECTION 2 - Loans cl.dta", keepusing(l3_amount) nogen
	merge 1:1 intervid using "data\indicator reinterviewed.dta", nogen
	merge 1:1 intervid using "data\Final_coordinates_distance_170112.dta"
	
*+++++++++++++++++++++++++++*
* (Table 1) - Randomization *
*+++++++++++++++++++++++++++*
/* Notes: Data source: Baseline household survey. 
   Unit of observation: household. 
   Panel A: sample includes only households also surveyed at endline. 
   Panel B: sample includes all households surveyed at baseline. */

*-- SOME DATA CLEANING/PREPARATION:
    rename l3_amount b_l3_amount
	gen b_resp_age2=b_resp_age*b_resp_age 
	gen resp_empl2060m=b_resp_es1 if b_resp_female==0 & b_resp_age>=20 & b_resp_age<=60
	gen resp_empl2060f=b_resp_es1 if b_resp_female==1 & b_resp_age>=20 & b_resp_age<=60
	egen b_hhmem=rowtotal(b_hhmem_male b_hhmem_female)
	gen b_resp_male=b_resp_gender==1
	replace b_loans=. if b_loans==999
	gen b_loan=b_loans!=0
	egen y_sources=rowtotal(b_y_selfempl b_y_agric b_y_shop b_y_bank b_y_manuf b_y_tourism b_y_privb b_y_governmnt b_y_remit b_y_benefit b_y_pension b_y_rent b_y_other)

*-- GLOBALS Variables in Table:
	#d ;
		global HHComp "b_hhmem b_adults b_children b_resp_male b_resp_age b_resp_ps";
		global CreditAccess "b_loan b_loans b_l_mfi b_l_bank b_l_percB"; //(we have data on 'other' but it is very very few...
		global CreditAmount "b_loanamount b_lamount_mfi b_lamount_bank";
		global SelfEmpl "y_sources b_y_tot yval_selfempl yval_agric b_hhmem_unemp b_hhmem_employed b_hhmem_retired b_resp_hrswork b_resp_hrsworkb ";
		global Consumption "b_foodc b_nondc b_durablec";
		global Distance "dist_sarajevo nearest_big";
	#d cr
	
	*--------------------------------------------------------------------*
	* Panel A: sample includes only households also surveyed at endline. *
	*--------------------------------------------------------------------*

	foreach x of varlist  $HHComp $CreditAccess $CreditAmount $SelfEmpl $Consumption $Distance {
		su `x' if followup==1
		gen BLobs`x'=r(N)
		su `x' if treatment==0 & followup==1
		gen BLobs`x'C=r(N)
		gen BLmean`x'=r(mean)
		gen BLsd`x'=r(sd)
		reg `x' treatment, robust
		gen beta`x' =_b[treatment]
		gen t_`x'=(_b[treatment]/_se[treatment])
		gen p_`x'=(2 * ttail(e(df_r), abs(_b[treatment]/_se[treatment])))
		}

	** DISPLAY RESULTS
	noi di as txt "PANEL A"
	noi di as txt "{col 32}" "Control Group" as txt "{col 62}" "Treatment-Control"
	noi di as txt "{col 22}" "Obs" as txt "{col 32}" "Obs(C)" as txt "{col 42}" "Mean" as txt "{col 52}" "StdDev" as txt "{col 62}" "Coeff" as txt "{col 72}" "p-value" 
	noi di as txt ""
	noi di as txt "Household composition"
	foreach v of varlist $HHComp  {
	   	noi di as txt "`v'" "{col 22}" as res %6.0f  BLobs`v' "{col 32}" as res %6.0f  BLobs`v'C "{col 42}" as res %6.3f  BLmean`v' "{col 52}" as res %6.3f  BLsd`v' "{col 62}"  as res %6.3f  beta`v' "{col 72}"  as res %6.3f   p_`v' 
		}
	noi di as txt ""
	noi di as txt "Access to credit:"
	foreach v of varlist $CreditAccess  {
	   	noi di as txt "`v'" "{col 22}" as res %6.0f  BLobs`v' "{col 32}" as res %6.0f  BLobs`v'C "{col 42}" as res %6.3f  BLmean`v' "{col 52}" as res %6.3f  BLsd`v' "{col 62}"  as res %6.3f  beta`v' "{col 72}"  as res %6.3f   p_`v' 
		}
	noi di as txt ""
	noi di as txt "Amount borrowed from (in BAM):"
	foreach v of varlist $CreditAmount  {
	   	noi di as txt "`v'" "{col 22}" as res %6.0f  BLobs`v' "{col 32}" as res %6.0f  BLobs`v'C "{col 42}" as res %6.1f  BLmean`v' "{col 52}" as res %6.1f  BLsd`v' "{col 62}"  as res %6.1f  beta`v' "{col 72}"  as res %6.3f   p_`v' 
		}
	noi di as txt ""
	noi di as txt "Employment Activities:"
	foreach v of varlist $SelfEmpl  {
	   	noi di as txt "`v'" "{col 22}" as res %6.0f  BLobs`v' "{col 32}" as res %6.0f  BLobs`v'C "{col 42}" as res %6.3f  BLmean`v' "{col 52}" as res %6.3f  BLsd`v' "{col 62}"  as res %6.3f  beta`v' "{col 72}"  as res %6.3f   p_`v' 
	   	*noi di as txt "`v'" "{col 22}" as res %6.0f  BLobs`v' "{col 32}" as res %6.0f  BLobs`v'C "{col 42}" as res %6.0f  BLmean`v' "{col 52}" as res %6.0f  BLsd`v' "{col 62}"  as res %6.0f  beta`v' "{col 72}"  as res %6.3f   p_`v' 
		}
	noi di as txt ""
	noi di as txt "Consumption:"
	foreach v of varlist $Consumption  {
	   	noi di as txt "`v'" "{col 22}" as res %6.0f  BLobs`v' "{col 32}" as res %6.0f  BLobs`v'C "{col 42}" as res %6.2f  BLmean`v' "{col 52}" as res %6.2f  BLsd`v' "{col 62}"  as res %6.2f  beta`v' "{col 72}"  as res %6.2f   p_`v' 
		}
	noi di as txt ""
	noi di as txt "Distance:"
	foreach v of varlist $Distance  {
	   	noi di as txt "`v'" "{col 22}" as res %6.0f  BLobs`v' "{col 32}" as res %6.0f  BLobs`v'C "{col 42}" as res %6.2f  BLmean`v' "{col 52}" as res %6.2f  BLsd`v' "{col 62}"  as res %6.2f  beta`v' "{col 72}"  as res %6.2f   p_`v' 
		}

	*--------------------------------------------------------------------*
	* Panel B: Attrition 												 *
	*--------------------------------------------------------------------*

	*-- SOME DATA CLEANING/PREPARATION:
		gen attrit=followup==0
		replace attrit=. if followup==.
		su attrit
		gen BLobsAT=r(N)
		su attrit if treatment==0 
		gen BLobsATC=r(N)
		gen BLmeanAT=r(mean)
		gen BLsdAT=r(sd)
	*-- Regression:
		reg attrit treatment, robust
		gen betaAT =_b[treatment]
		gen p_AT=(2 * ttail(e(df_r), abs(_b[treatment]/_se[treatment])))

	** DISPLAY RESULTS
	noi di as txt "PANEL B"
	noi di as txt "{col 32}" "Control Group" as txt "{col 62}" "Treatment-Control"
	noi di as txt "{col 22}" "Obs" as txt "{col 32}" "Obs(C)" as txt "{col 42}" "Mean" as txt "{col 52}" "StdDev" as txt "{col 62}" "Coeff" as txt "{col 72}" "p-value" 
	noi di as txt ""
	noi di as txt "Attrition"
   	noi di as txt "Not surveyed at endline" "{col 22}" as res %6.0f  BLobsAT "{col 32}" as res %6.0f  BLobsATC "{col 42}" as res %6.3f  BLmeanAT "{col 52}" as res %6.3f  BLsdAT "{col 62}"  as res %6.3f  betaAT "{col 72}"  as res %6.3f   p_AT 
