/*==========================================================*
Paper: 		"The impacts of microcredit: Evidence from B&H"

Purpose:		This do-file: Dealing with attrition by 
				reweighting the data with the inverse probability 
				of being observed, following DiNardo, Fortin 
				and Lemieux (1996)

Code Author: 	IFS
Date created: 	Feb 2013
Last modified:  

Note:			XXX 
*===========================================================*/
capture log close
set more off
adopath+"C:\ado"
drop _all
global workdir "XXX"		
cap mkdir "${workdir}"	
cd "${workdir}"						

*-- PUT DATA SET TOGETHER: 
	use "data\Baseline\Covariates Bosnia Baseline.dta", clear
	gen b_resp_age2=b_resp_age*b_resp_age 
	* merge with the indicator of whether someone was re-interviewed or not
	merge 1:1 intervid using "data\indicator reinterviewed.dta", nogen
	* merge in loan officer judgements:
	merge 1:1 intervid using "data\Baseline\LOs view of MCs.dta" // 265 unmatched


*-- GLOBALS:
	#d ;
		global Xvar "b_resp_female b_resp_age b_resp_age2 b_resp_ms1 b_resp_ms4 b_resp_ms5  b_resp_ss b_resp_ul
			 b_kids_05 b_kids_610 b_kids_1116 b_hhmem_female  b_hhmem_employed b_hhmem_school b_hhmem_retired";
		global Asset "bln_assetvalue b_dw_house b_dw_own b_savings_yn b_loans";
		global Ytype "b_y_selfempl  b_y_agric b_y_shop  b_y_manuf b_y_privb b_y_governmnt b_y_remit b_y_benefit b_y_pension b_y_rent";
		global Yamount "bln_ytot";
		global Shocks "b_jobloss_yn b_badharvest_yn b_illnessearn_yn b_illnessnonearn_yn b_deathearn_yn b_deathnonearn_yn b_emplleft_yn b_crime_yn b_compet_yn b_otherloss_yn b_jobgain_yn";
		global Bus "b_bm_own";
		global Outlook " b_present_successful b_past_successful b_future_successful  b_compare_peers b_future_optimistic";
		global XAppl1 "appl_competent12 appl_clever12 appl_trustworthy12 appl_aggressive12";
		global XReq1 "eki_req_collateral eki_req_repcap eki_req_busicap";
		global XReqnotmet "ekireq_col ekireq_repcap ekireq_busicap";
		global XInt "eki_req_coll eki_req_repcap ";
		global Worry "mostworry_1 mostworry_2 mostworry_4 mostworry_5";
	#d cr


*-- SOME DATA CLEANING/PREPARATION:
	foreach x of varlist appl_competent appl_reliable appl_trustworthy appl_knowledge appl_experience appl_integrated appl_clever appl_risktaker appl_fighter appl_aggressive appl_stable appl_insecure {
		gen `x'12=`x'==1
		replace `x'12=1 if `x'==2
		replace `x'12=. if `x'==.
		}
		
	gen coll_worry=eki_req_most==1
	replace coll_worry=. if eki_req_most==.

** -------------------------------------------- ** 
** (1) Estimate probability of being observed/attrition:
** -------------------------------------------- ** 
	gen observed=followup==1
	
	probit observed treatment $Xvar, robust 
		predict p_observed1
		replace p_observed1=1/p_observed1
	probit observed treatment $Xvar $Bus $Asset $Ytype $Yamount $Outlook $Shock, robust 
		predict p_observed2
		replace p_observed2=1/p_observed2
	probit observed treatment $Xvar $Bus $Asset $Ytype $Yamount $Outlook $Shock $XAppl1 $XReq1, robust 
		predict p_observed3
		replace p_observed3=1/p_observed3
	keep intervid p_observed1 p_observed2 p_observed3 treatment
	
	save "data\Prob being observed_do(Table TA7).dta", replace

** -------------------------------------------- ** 
** (2) Re-estimate impacts:
** -------------------------------------------- ** 

*-- PUT DATA SET TOGETHER: 
	use "data\Baseline\Covariates Bosnia Baseline.dta", clear
	gen b_resp_age2=b_resp_age*b_resp_age 
	merge 1:1 intervid using "data\indicator reinterviewed.dta", nogen
	* merge in OUTCOMES:
	merge 1:1 intervid using "data\Followup\Employment status respondent.dta", nogen keepusing(resp_es2)
	merge 1:1 intervid using "data\Followup\SECTION 2 - Loans cl.dta", nogen
	merge 1:1 intervid using "data\Followup\SECTION 3 - Consumption cl.dta", nogen /*keepusing(durablec nondc foodc_h foodc_o cigalcc foodc)*/
	merge 1:1 intervid using "data\Followup\SECTION 4 - Assets cl.dta",  nogen
	merge 1:1 intervid using "data\Followup\SECTION 5 - Income cl.dta", nogen 
	merge 1:1 intervid using "data\Followup\SECTION 6 - Business cl.dta", nogen keepusing(bm_own bm_expenses bm_revenue bm_profit bm_staff_FT bm_staff_PT bm_staff_T  bm_staffsalary   bm_staff_hhft bm_staff_hhpt bm_staff_hht bm_staff_hhpay bm_staff_outft bm_staff_outpt bm_staff_outt bm_staff_outpay bm_trade bm_service bm_agric bm_prod  bm_reg)
	merge 1:1 intervid using "data\Followup\SECTION 7 - Savingscl.dta", nogen keepusing(savings_avg savings_yn contrib_weekly contrib_monthly contrib_yearly contrib_no sav_busexp sav_edu sav_med sav_old sav_repair sav_emergency sav_cons sav_bequest sav_debt sav_festival sav_other)
	merge 1:1 intervid using "data\Followup\SECTION 8 - Household roster cl.dta", nogen
	merge 1:1 intervid using "data\Followup\SECTION 9 - Shocks cl.dta", nogen keepusing(jobloss_yn jobgain_yn othergain_yn badharvest_yn illnessearn_yn illnessnonearn_yn deathearn_yn deathnonearn_yn emplleft_yn crime_yn compet_yn otherloss_yn jobgain_yn othergain_yn jobloss_ydec badharvest_ydec illnessearn_ydec illnessnonearn_ydec deathearn_ydec deathnonearn_ydec emplleft_ydec crime_ydec compet_ydec otherloss_ydec)
	merge 1:1 intervid using "data\Followup\SECTION 10 - Stress cl.dta", nogen
	merge 1:1 intervid using "data\incentive given.dta", nogen
	merge 1:1 intervid using "data\Prob being observed_do(Table TA7).dta", nogen

*-- SOME DATA CLEANING/PREPARATION:
	gen respedu_l=b_resp_ps==1
	gen respedu_h=b_resp_ps==0
	gen t_edul=treatment*respedu_l
	gen t_eduh=treatment*respedu_h
	gen nobus=b_bm_own==0
	gen t_busin=treatment*b_bm_own
	gen t_nobus=treatment*nobus

*-- GLOBALS:
	#d ;
		global Xvar "b_resp_female b_resp_age b_resp_age2 b_resp_ms1 b_resp_ms4 b_resp_ms5  b_resp_ss b_resp_ul
			 b_kids_05 b_kids_610 b_kids_1116 b_hhmem_female  b_hhmem_employed b_hhmem_school b_hhmem_retired";
		global Edu "t_edul t_eduh respedu_l";
		global Busi "t_busi t_nobus b_bm_own";
		global Xvaredu "b_resp_female b_resp_age b_resp_age2 b_resp_ms1 b_resp_ms4 b_resp_ms5  
			 b_kids_05 b_kids_610 b_kids_1116 b_hhmem_female  b_hhmem_employed b_hhmem_school b_hhmem_retired";
	#d cr
	

	
/* --------------------------------------------------------------------------------------
   ---------------------------------------------------------------------------------------
   We next conduct the impact analysis by Table as presented in the paper, this time around
   re-weighing all regressions.   
   ---------------------------------------------------------------------------------------
   ---------------------------------------------------------------------------------------*/

*+++++++++++++++++++++++++++*
* (Table 2) - Credit        *
*+++++++++++++++++++++++++++*
	
*-- GLOBAL:
	global T2 "loan loans f_l_mfi f_l_bank"
	
*-- Additional DATA CLEANING/PREPARATION:
	egen f_l_mfi=rowmax(l1_2 l2_2 l3_2)
	la var f_l_mfi "=1 if one of outstanding loans is with MFI"
	egen f_l_bank=rowmax(l1_1 l2_1 l3_1)
	la var f_l_mfi "=1 if one of outstanding loans is with Bank"
	egen f_l_percB=rowmean(l1_percbus l2_percbus l3_percbus)
	la var f_l_percB "Average percentage of 3 main outstanding loans used for business investment"
	forvalues i=1(1)3 {
		gen temp`i'_mfi=l`i'_amount if l`i'_2==1
		gen temp`i'_bank=l`i'_amount if l`i'_1==1
		}
	egen f_lamount_mfi=rowmean(temp1_mfi temp2_mfi temp3_mfi)
	egen f_lamount_bank=rowmean(temp1_bank temp2_bank temp3_bank)
	foreach x of varlist f_lamount_mfi f_lamount_bank {
		replace `x'=0 if `x'==.
		replace `x'=. if `x'==999999
		replace `x'=. if `x'==99999
		}
	egen f_loanamount=rowtotal(l1_amount l2_amount l3_amount) 
	gen loan=loans!=0 
	su loan loans f_l_mfi f_l_bank f_l_percB f_lamount_mfi f_lamount_bank f_loanamount
	foreach x of varlist loan loans f_l_mfi f_l_bank f_l_percB f_lamount_mfi f_lamount_bank f_loanamount {
		replace `x'=0 if `x'==. & followup==1
		}

*-- ESTIMATION:
	// Re-weighted Impact estimate regressions:
	local table replace
	foreach x of varlist $T2 {
		qui reg `x' treat $Xvar if followup==1, robust  	// Overall
		outreg2 using "output\Impact Estimates - reweighted\T2 Credit (reweighted).xls", `table'
		forvalues i=1(1)3 {
			qui reg `x' treat $Xvar if followup==1 [pweight=p_observed`i'], robust  	// Overall
			outreg2 using "output\Impact Estimates - reweighted\T2 Credit (reweighted).xls", append
			}
		local table append 
		}
		
	
*+++++++++++++++++++++++++++++++++++++*
* (Table 3) - (Self-Empl Activities)  *
*+++++++++++++++++++++++++++++++++++++*
*-- GLOBAL:
	global T3 "assetvalue* inventory bm_revenue bm_expenses bm_profit y_selfempl bm_own bm_service bm_agric b_start b_close bm_profit01"
	global T3add "assetvalue* inventory bm_revenue* bm_expenses* bm_profit* bm_profitcalc* y_selfempl bm_own bm_service bm_agric b_start b_close bm_profit01"
	global T3staff "bm_staff_outft bm_staff_outpt bm_staff_outt staff_out bm_staff_hhft bm_staff_hhpt bm_staff_hht staff_hh"
	
*-- Additional DATA CLEANING/PREPARATION:
	gen inventory=inventory_val!=0
	gen b_start=1 if b_bm_own==0 & bm_own==1
		la var b_start "=1 if HH has started a business (since baseline)"
	gen b_close=1 if b_bm_own==1 & bm_own==0
		la var b_close "=1 if HH has closed their business (since baseline)"
	gen bm_profit01=bm_profit!=0
		replace bm_profit01=. if bm_profit==.
	egen staff_out=rowtotal(bm_staff_outft bm_staff_outpt bm_staff_outt)
	egen staff_hh=rowtotal(bm_staff_hhft bm_staff_hhpt bm_staff_hht)
	gen bm_profitcalc=bm_revenue-bm_expenses

	foreach x of varlist $T3add $T3staff {
		replace `x'=0 if `x'==. & followup==1
		replace `x'=. if followup==0
		}
	foreach x of varlist bm_expenses bm_revenue bm_profit bm_profitcalc assetvalue {
		// We trim value variables -- highest three percentiles
		su `x', d
		gen `x'TR1p=`x' if `x'<=r(p99)
		su `x'TR1p, d
		gen `x'TR2p=`x' if `x'<=r(p99)
		su `x'TR2p, d
		gen `x'TR3p=`x' if `x'<=r(p99)
		}

*-- ESTIMATION:
	// Re-weighted Impact estimate regressions:
	local table replace
	foreach x of varlist $T3 {
		qui reg `x' treat $Xvar if followup==1, robust  	// Overall
		outreg2 using "output\Impact Estimates - reweighted\T3 Self-empl (reweighted).xls", `table'
		forvalues i=1(1)3 {
			qui reg `x' treat $Xvar if followup==1 [pweight=p_observed`i'], robust  	// Overall
			outreg2 using "output\Impact Estimates - reweighted\T3 Self-empl (reweighted).xls", append
			}
		local table append 
		}

*++++++++++++++++++++++*
* (Table 4) - Income   *
*++++++++++++++++++++++*
*-- GLOBAL:
	global T4Income01 "y_selfempl yval_selfempl y_wages yval_wages y_remit yval_remit y_benefit yval_benefit"
	
*-- Additional DATA CLEANING/PREPARATION:
	foreach x of varlist y_selfempl y_agric y_shop y_manuf  y_privb y_governmnt y_remit y_benefit y_pension y_rent {
		replace `x'=0 if `x'==.
		replace `x'=. if followup==0
		}
	egen y_wages=rowmax(y_agric y_shop y_manuf  y_privb y_governmnt)
	egen yval_wages=rowtotal(yval_agric yval_shop yval_manuf yval_privb yval_governmnt)

*-- ESTIMATION:
	local table replace
	foreach x of varlist $T4Income01 {
		qui reg `x' treat $Xvar if followup==1, robust  	// Overall
		outreg2 using "output\Impact Estimates - reweighted\T4 Income (reweighted).xls", `table'
		forvalues i=1(1)3 {
			qui reg `x' treat $Xvar if followup==1 [pweight=p_observed`i'], robust  	// Overall
			outreg2 using "output\Impact Estimates - reweighted\T4 Income (reweighted).xls", append
			}
		local table append 
		}
		
		
*++++++++++++++++++++++++++*
* (Table 5) - Consumption  *
*++++++++++++++++++++++++++*
*-- GLOBAL:
	global T5 "totalc_cap durablec nondcTR foodc educ_yr cigalcc recre_yr HDGI savings_avg"
		
*-- Additional DATA CLEANING/PREPARATION:
	gen durableTR=durable if durabl<=600000	// exlcudes one obs
	gen nondcTR=nondc if nond<=2800	// exluded one obs
	gen educ_yrTR=educ_yr if educ_yr<25000	//excludes one obs
	
	foreach x of varlist foodc_h foodc_o cigalcc nondc durablec durableTR nondcTR recre_m{
		gen `x'temp=`x'
		replace `x'temp=0 if `x'temp==.
		}
	gen totalc=foodc_htemp*52 +foodc_otemp*52+ cigalcctemp*52 + nondctemp*12+ durablectemp
		lab var totalc "Total consumption expenditure in last year"
	gen totalcTR=foodc_htemp*52 +foodc_otemp*52+ cigalcctemp*52 + nondcTRtemp*12+ durableTRtemp
	gen nondc_tot=nondc+foodc+cigalcc
	gen nondcTR_tot=nondcTR+foodc+cigalcc
	gen temptation_yr=cigalcc+recre_mtemp*12
	gen recre_yr=recre_m*12
	foreach x of varlist totalc totalcTR foodc_h foodc_o foodc educ_yr educ_yrTR temptation_yr cigalcc  nondc durablec durableTR nondcTR nondc_tot nondcTR_tot recre_yr {
		*replace `x'=0 if `x'==. 
		replace `x'=. if followup==0 	
		gen miss_`x'=1 if `x'==. & followup==1
		}
	egen hhmem=rowtotal(hhmem_male hhmem_female)
	gen totalc_cap=totalc/hhmem
		replace totalc_cap=0 if totalc_cap==. & followup==1
		replace totalc_cap=. if followup==0
	
	* home durable good index:
	foreach x of varlist house_nr land_nr car_nr lorry_nr animals_nr motorbike_nr computer_nr tools_nr inventory_nr mobile_nr tv_nr video_nr radio_nr electrappl_nr generator_nr fridge_nr oven_nr washmachine_nr {
		gen `x'01=`x'!=0 & `x'!=.
		}
	factor *_nr01, pcf // Principal Component Factor analysis
	rotate
	predict HDGI 
	
	*savings
	replace savings_yn=0 if savings_yn==2
	replace savings_yn=1 if savings_yn==9
	replace savings_yn=0 if savings_yn==.	
	replace savings_yn=. if followup==0	
	replace savings_avg=0 if savings_avg==.	
	replace savings_avg=. if followup==0	
	foreach x of varlist  contrib_weekly contrib_monthly contrib_yearly contrib_no sav_busexp sav_edu sav_med sav_old sav_repair sav_emergency sav_cons sav_bequest sav_debt sav_festival sav_other {
		replace `x'=0 if `x'!=1 & savings_yn==1
		replace `x'=0 if `x'==.	
		replace `x'=. if followup==0	
		}


*-- ESTIMATION:
	// Re-weighted Impact estimate regressions:
	local table replace
	foreach x of varlist $T5 {
		qui reg `x' treat $Xvar if followup==1, robust  	// Overall
		outreg2 using "output\Impact Estimates - reweighted\T5 Consumption (reweighted).xls", `table'
		forvalues i=1(1)3 {
			qui reg `x' treat $Xvar if followup==1 [pweight=p_observed`i'], robust  	// Overall
			outreg2 using "output\Impact Estimates - reweighted\T5 Consumption (reweighted).xls", append
			}
		local table append 
		}
		
*++++++++++++++++++++++++++++*
* (Table 6) - Labour Supply  *
*++++++++++++++++++++++++++++*

*-- DATA:	
	merge 1:1 intervid using "data\Followup\Household level info working hrs and schooling - teenagers.dta"
	drop _m
	merge 1:1 intervid using "data\Followup\labour supply and schooling outcomes - hh level.dta"
	
*-- GLOBAL:
	global LabourSupply "$AllAdults $AllAdultsPM $Teens $TeensPM $Teens1619 $Teens1619PM"
	global AllAdults "hrswork_1664 hrswork_bus1664 hrswork_oa1664"
	global AllAdultsPM "hrswork_1664pm hrswork_bus1664pm hrswork_oa1664pm"
	global Teens "hrswork_teen hrswork_busteen hrswork_oateen"
	global TeensPM "hrswork_teenpm hrswork_busteenpm hrswork_oateenpm"
	global Teens1619 "hrswork_tot1619 hrswork_bus1619 hrswork_oa1619"
	global Teens1619PM "hrswork_pm1619 hrswork_buspm1619 hrswork_oa1619pm"
		
*-- Additional DATA CLEANING/PREPARATION:
	gen hrswork_tot=0
	gen hrswork_1664=0
	gen hrswork_teen=0
	forvalues i=1(1)9 {
		gen age0`i'=2010- o8_2_g0`i' // create year variable
		replace  o8_9_0`i'=0 if  o8_9_0`i'==.
		replace hrswork_tot=hrswork_tot+ o8_9_0`i'
		replace hrswork_tot=0 if hrswork_tot==.
		replace hrswork_tot=. if followup==0
		replace hrswork_1664=hrswork_1664+ o8_9_0`i' if age0`i'>=16 & age0`i'<=64	// create working hours for HH mem of working age
		replace hrswork_1664=0 if hrswork_1664==.
		replace hrswork_1664=. if followup==0
		replace hrswork_teen=hrswork_teen+ o8_9_0`i' if age0`i'>=13 & age0`i'<=19	// create working hours for HH mem of working age
		replace hrswork_teen=0 if hrswork_teen==.
		replace hrswork_teen=. if followup==0
		}
	forvalues i=10(1)12 {
		gen age`i'=2010- o8_2_g`i'
		replace  o8_9_`i'=0 if  o8_9_`i'==.
		replace hrswork_tot=hrswork_tot+ o8_9_`i'
		replace hrswork_tot=0 if hrswork_tot==.
		replace hrswork_tot=. if followup==0
		replace hrswork_1664=hrswork_1664+ o8_9_`i' if age`i'>=16 & age`i'<=64	// create working hours for HH mem of working age
		replace hrswork_1664=0 if hrswork_1664==.
		replace hrswork_1664=. if followup==0
		replace hrswork_teen=hrswork_teen+ o8_9_`i' if age`i'>=13 & age`i'<=19	// create working hours for ttenage HH mem 
		replace hrswork_teen=0 if hrswork_teen==.
		replace hrswork_teen=. if followup==0
		}
	gen hrswork_bus=0
	gen hrswork_bus1664=0
	gen hrswork_busteen=0
	forvalues i=1(1)9 {
		replace  o8_10_0`i'=0 if  o8_10_0`i'==.
		replace hrswork_bus=hrswork_bus+ o8_10_0`i'
		replace hrswork_bus=0 if hrswork_bus==.
		replace hrswork_bus=. if followup==0
		replace hrswork_bus1664=hrswork_bus1664+ o8_10_0`i' if age0`i'>=16 & age0`i'<=64	// create working hours on bus for HH mem of working age
		replace hrswork_bus1664=0 if hrswork_bus1664==.
		replace hrswork_bus1664=. if followup==0
		replace hrswork_busteen=hrswork_busteen+ o8_10_0`i' if age0`i'>=13 & age0`i'<=19	
		replace hrswork_busteen=0 if hrswork_busteen==.
		replace hrswork_busteen=. if followup==0
		}
	forvalues i=10(1)12 {
		replace  o8_10_`i'=0 if  o8_10_`i'==.
		replace hrswork_bus=hrswork_bus+ o8_10_`i'
		replace hrswork_bus=0 if hrswork_bus==.
		replace hrswork_bus=. if followup==0
		replace hrswork_bus1664=hrswork_bus1664+ o8_10_`i' if age`i'>=16 & age`i'<=64	// create working hours on bus for HH mem of working age
		replace hrswork_bus1664=0 if hrswork_bus1664==.
		replace hrswork_bus1664=. if followup==0
		replace hrswork_busteen=hrswork_busteen+ o8_10_`i' if age`i'>=13 & age`i'<=19	
		replace hrswork_busteen=0 if hrswork_busteen==.
		replace hrswork_busteen=. if followup==0
		}
	replace hrswork_tot=. if hrswork_tot>600
	replace hrswork_1664=. if hrswork_1664>600
	// gen count of nr of childen 16-19 in hh & of working age & teens
	gen count1664=0
	gen countteen=0
	forvalues y=17(1)20 {
		gen count16`y'=0
		forvalues i=1(1)9 {
			replace count16`y'=count16`y'+1 if age0`i'>=16 & age0`i'<=`y'
			}
		forvalues i=10(1)12 {
			replace count16`y'=count16`y'+1 if age`i'>=16 & age`i'<=`y'
			}
		}
	forvalues i=1(1)9 {
		replace count1664=count1664+1 if age0`i'>=16 & age0`i'<=64
		replace countteen=countteen+1 if age0`i'>=13 & age0`i'<=20
		}
	forvalues i=10(1)12 {
		replace count1664=count1664+1 if age`i'>=16 & age`i'<=64
		replace countteen=countteen+1 if age`i'>=13 & age`i'<=20
		}
	*egen hhmem=rowtotal(hhmem_male hhmem_female)
	gen hrswork_totpm=hrswork_tot/hhmem
	gen hrswork_buspm=hrswork_bus/hhmem
	gen hrswork_1664pm=hrswork_1664/count1664
	gen hrswork_bus1664pm=hrswork_bus1664/count1664
	gen hrswork_teenpm=hrswork_teen/countteen
	gen hrswork_busteenpm=hrswork_busteen/countteen

	gen hrswork_oa1664=hrswork_1664-hrswork_bus1664			// hrs worked on other than business-activities (all hh mem of working age)
	gen hrswork_oa1664pm=hrswork_1664pm-hrswork_bus1664pm	// hrs worked on other than business-activities per hh member (all hh mem of working age)
	gen hrswork_oa1619=hrswork_tot1619-hrswork_bus1619		// hrs worked on other than business-activities (age 16-19)
	gen hrswork_oa1619pm=hrswork_pm1619-hrswork_buspm1619	// hrs worked on other than business-activities per member (age 16-19)
	gen hrswork_oateen=hrswork_teen-hrswork_busteen		// hrs worked on other than business-activities (age 16-19)
	gen hrswork_oateenpm=hrswork_teenpm-hrswork_busteenpm	// hrs worked on other than business-activities per member (age 16-19)
	
	foreach x of varlist hrswork_tot  $AllAdults $AllAdultsPM $Teens $TeensPM $Teens1619 $Teens1619PM {
		replace `x'=0 if `x'==.	
		replace `x'=. if followup==0	
		}
		

*-- ESTIMATION:
	// Re-weighted Impact estimate regressions:
	local table replace
	foreach x of varlist $AllAdults $Teens1619 {
		qui reg `x' treat $Xvar if followup==1, robust  	// Overall
		outreg2 using "output\Impact Estimates - reweighted\T6 Labour Supply (reweighted).xls", `table'
		forvalues i=1(1)3 {
			qui reg `x' treat $Xvar if followup==1 [pweight=p_observed`i'], robust  	// Overall
			outreg2 using "output\Impact Estimates - reweighted\T6 Labour Supply (reweighted).xls", append
			}
		local table append 
		}


*+++++++++++++++++++++++++++++++*
* (Table 7) - Social		    *
*+++++++++++++++++++++++++++++++*
* Note: We first estimate the stress and having kids 16-19 results, we turn below to the schooling variables.

*-- DATA:	
	merge 1:1 intervid using "data\Followup\Kids1619at followup.dta", nogen
	
*-- GLOBAL:
	global T7 "stress kids1619 kids_1619"
		
*-- Additional DATA CLEANING/PREPARATION:
	rename stress_1 stress
	foreach x of varlist  stress {
		replace `x'=0 if `x'==.
		replace `x'=. if follow==0
		}
	gen kids1619=kids_1619!=0
	
*-- ESTIMATION:
		local table replace
		foreach x of varlist $T7  {
			su `x' if followup==1 & treatment==0
			qui reg `x' treat $Xvar if followup==1, robust  	// Overall
			outreg2 using "output\Impact Estimates - reweighted\T7 Social (reweighted).xls", `table'
			forvalues i=1(1)3 {
				qui reg `x' treat $Xvar if followup==1 [pweight=p_observed`i'], robust  	// Overall
				outreg2 using "output\Impact Estimates - reweighted\T7 Social (reweighted).xls", append
				}
			local table append 
			}
		
*+++++++++++++++++++++++++++++++++*
* (Table 7) - Social - Schooling *
*+++++++++++++++++++++++++++++++++*
// Individual level regressions
	
*-- DATA:	
	use "data\Followup\SECTION 8 - Household roster cl.dta", clear
	set more off
	
*-- GLOBAL:
		#d ;
			global Xvar "b_resp_female b_resp_age b_resp_age2 b_resp_ms1 b_resp_ms4 b_resp_ms5  b_resp_ss b_resp_ul
				 b_kids_05 b_kids_610 b_kids_1116 b_hhmem_female  b_hhmem_employed b_hhmem_school b_hhmem_retired";
			global Edu "t_edul t_eduh respedu_l";
			global Busi "t_busi t_nobus b_bm_own";
			global Xvaredu "b_resp_female b_resp_age b_resp_age2 b_resp_ms1 b_resp_ms4 b_resp_ms5  
				 b_kids_05 b_kids_610 b_kids_1116 b_hhmem_female  b_hhmem_employed b_hhmem_school b_hhmem_retired";
		#d cr

*-- Additional DATA CLEANING/PREPARATION:
	keep  intervid branch treatment followup o8_9_* o8_10_*  o8_2_m* o8_2_g*  o8_3_* o8_5_* o8_4_* o8_6_* o8_7_*
		forvalue i=1(1)9 { 
				rename o8_2_m0`i' o8_2_m`i'
				rename o8_2_g0`i' o8_2_g`i'
				rename o8_9_0`i' o8_9_`i'
				rename o8_10_0`i' o8_10_`i'
				rename o8_3_0`i' o8_3_`i'
				rename o8_4_0`i' o8_4_`i'
				rename o8_5_0`i' o8_5_`i'
				rename o8_7_0`i' o8_7_`i'
				rename o8_6_0`i' o8_6_`i'
			}
	reshape long o8_9_ o8_10_ o8_2_m o8_2_g  o8_3_ o8_4_ o8_5_ o8_6_ o8_7_, i(intervid) j(hhmem)
		rename o8_9_ hrswork_tot
		rename o8_10_  hrswork_bus
		rename o8_3_ sex
		rename o8_4_ maritalst
		rename o8_5_ econstatus
		rename o8_6_ highestgrade
		rename o8_7_ attendingschool
		
		drop if sex==. & maritalst==. & econstatus==. & highestgrade==. & hrswork_tot==.
		replace hrswork_tot=0 if hrswork_tot==.
		replace hrswork_tot=. if followu==0
		replace hrswork_bus=0 if hrswork_bus==.
		replace hrswork_bus=. if followu==0
		replace hrswork_tot=. if hrswork_tot>100
		replace hrswork_b=. if hrswork_b>100
		replace attending=0 if attending==2
		replace attending=. if followu==0
		
		* Construct age from birthdate
		gen age=2010- o8_2_g
			move age  o8_2_m
		sort intervid
		merge m:1 intervid using "data\Baseline\Covariates Bosnia Baseline.dta" 
		tab _m 	//(257 obs not matched)
		drop if _m==2
		drop _m
		merge m:1 intervid using "data\Prob being observed_do(Table TA7).dta", nogen
		gen b_resp_age2=b_resp_age*b_resp_age 
		gen respedu_l=b_resp_ps==1
		gen respedu_h=b_resp_ps==0
		gen t_edul=treatment*respedu_l
		gen t_eduh=treatment*respedu_h
		gen nobus=b_bm_own==0
		gen t_busin=treatment*b_bm_own
		gen t_nobus=treatment*nobus
		
		
*-- ESTIMATION:
		reg attendingschool treatment $Xvar if age>6 & age<16, robust cl(intervid)  
			su attendingschool if followup==1 & treatment==0 & age>6 & age<16
			local meanCAS2=r(mean)
			outreg2 using "output\Impact Estimates - reweighted\T7 Social (reweighted)", addstat(Mean C, `meanCAS2') append
			forvalues i=1(1)3 {
				qui reg attendingschool treatment $Xvar if age>6 & age<16 [pweight=p_observed`i'], robust  	// Overall
				outreg2 using "output\Impact Estimates - reweighted\T7 Social (reweighted).xls", append
				}
		reg attendingschool treatment $Xvar if age>15 & age<20, robust cl(intervid)  
			su attendingschool if followup==1 & treatment==0 & age>6 & age<16
			local meanCAS2=r(mean)
			outreg2 using "output\Impact Estimates - reweighted\T7 Social (reweighted)", addstat(Mean C, `meanCAS2') append
			forvalues i=1(1)3 {
				qui reg attendingschool treatment $Xvar if age>15 & age<20 [pweight=p_observed`i'], robust  	// Overall
				outreg2 using "output\Impact Estimates - reweighted\T7 Social (reweighted).xls", append
				}

